@@ -1,4 +1,7 @@
 # -*- coding: utf-8 -*-
+
+from zope.annotation.interfaces import IAnnotations
+
 import json
 import os
 
@@ -32,6 +35,11 @@ def get_json(json_filename):
         return json_procedures_raw_mock
 
 
+def clear_cache(request):
+    annotations = IAnnotations(request)
+    del annotations["plone.memoize"]
+
+
 def make_named_image(filename="plone.png"):
     path = os.path.join(os.path.dirname(__file__), f"resources/{filename}")
     with open(path, "rb") as f:
